==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fLushr.h <==
// class soot.coffi.Instruction_Lushr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 5220b2d18f8a0b34 soot_coffi_Instruction__5fLushr
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fLushr_H_
#define _JC_soot_coffi_Instruction__5fLushr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLushr$sub_refs	_jc_soot_coffi_Instruction__5fLushr$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLushr$sub_nonrefs	_jc_soot_coffi_Instruction__5fLushr$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLushr$refs	_jc_soot_coffi_Instruction__5fLushr$refs;
typedef struct _jc_soot_coffi_Instruction__5fLushr$nonrefs	_jc_soot_coffi_Instruction__5fLushr$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLushr$object	_jc_soot_coffi_Instruction__5fLushr$object;

typedef const struct _jc_soot_coffi_Instruction__5fLushr$vmethods	_jc_soot_coffi_Instruction__5fLushr$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLushr$vtable	_jc_soot_coffi_Instruction__5fLushr$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLushr$vtype	_jc_soot_coffi_Instruction__5fLushr$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLushr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLushr$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLushr$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLushr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fLushr$vmethods	soot_coffi_Instruction__5fLushr;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLushr$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLushr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLushr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLushr$refs {
    _jc_soot_coffi_Instruction__5fLushr$sub_refs	soot_coffi_Instruction__5fLushr;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLushr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLushr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fLushr$sub_nonrefs	soot_coffi_Instruction__5fLushr;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLushr$object {
	_jc_soot_coffi_Instruction__5fLushr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLushr$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLushr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLushr$vtype _jc_soot_coffi_Instruction__5fLushr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLushr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLushr$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLushr_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fLushr.h <==
// class soot.coffi.Instruction_Lushr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 5220b2d18f8a0b34 soot_coffi_Instruction__5fLushr
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fLushr_H_
#define _JC_soot_coffi_Instruction__5fLushr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLushr$sub_refs	_jc_soot_coffi_Instruction__5fLushr$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLushr$sub_nonrefs	_jc_soot_coffi_Instruction__5fLushr$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLushr$refs	_jc_soot_coffi_Instruction__5fLushr$refs;
typedef struct _jc_soot_coffi_Instruction__5fLushr$nonrefs	_jc_soot_coffi_Instruction__5fLushr$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLushr$object	_jc_soot_coffi_Instruction__5fLushr$object;

typedef const struct _jc_soot_coffi_Instruction__5fLushr$vmethods	_jc_soot_coffi_Instruction__5fLushr$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLushr$vtable	_jc_soot_coffi_Instruction__5fLushr$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLushr$vtype	_jc_soot_coffi_Instruction__5fLushr$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLushr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLushr$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLushr$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLushr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fLushr$vmethods	soot_coffi_Instruction__5fLushr;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLushr$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLushr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLushr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLushr$refs {
    _jc_soot_coffi_Instruction__5fLushr$sub_refs	soot_coffi_Instruction__5fLushr;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLushr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLushr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fLushr$sub_nonrefs	soot_coffi_Instruction__5fLushr;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLushr$object {
	_jc_soot_coffi_Instruction__5fLushr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLushr$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLushr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLushr$vtype _jc_soot_coffi_Instruction__5fLushr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLushr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLushr$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLushr_H_ */
